@@ -353,14 +353,14 @@ static void MakeAfmFiles(FOND *fond,FILE *f, int isfixed,char *origfilename) {
 	    for ( k=0; k<fond->stylekerns[i].kernpairs; ++k ) {
 		const char *name1, *name2;
 		struct kerns *kp = &fond->stylekerns[i].kerns[k];
-		if ( kp->ch1<=256 )
+		if ( 1 /* kp->ch1<=256 */ )
 		    name1 = macnames[kp->ch1];
 		else {
 		    sprintf( buffer, "char%04x", kp->ch1 );
 		    name1 = buffer;
 		}
 		if ( name1==NULL ) name1 = ".notdef";
-		if ( kp->ch2<=256 )
+		if ( 1 /* kp->ch2<=256 */ )
 		    name2 = macnames[kp->ch2];
 		else {
 		    sprintf( fontname, "char%04x", kp->ch2 );
@@ -955,9 +955,7 @@ static int HasResourceFork(char *filename,PSFONT *psfont) {
 return( ret );
 }
 #else
-	/* OS/9 and before */
-#include "MacFiles.h"
-
+	/* OS/9 and before, these calls depreciated in X.4 */
 static int HasResourceFork(char *filename,PSFONT *psfont) {
     /* If we're on a mac, we can try to see if we've got a real resource fork */
     FSRef ref;
@@ -1226,7 +1224,7 @@ int main(int argc, char **argv) {
 		fprintf( stderr, " if -force is given you will not be asked about replacing existing files\n" );
 		fprintf( stderr, " if -inquire is given you will be asked about writing each file (whether\n" );
 		fprintf( stderr, "\tit exists or not). -inquire overrides -force.\n" );
-		fprintf( stderr, " if -show is given you will not be told about each file created.\n" );
+		fprintf( stderr, " if -show is given you will be told about each file created.\n" );
 		fprintf( stderr, " if -latin1 is given nfnts will be reencoded to latin1 (else left in mac roman)\n" );
 		fprintf( stderr, " if -trackps is given then any postscript files referenced by a FOND\n" );
 		fprintf( stderr, "\twill be loaded and processed.\n" );
